/*****************************************************************************
 *	axcac01s.c
 *
 *	AXC-AC01
 *	Copyright ADTEK SYSTEM SCIENCE Co.,Ltd.
 *
 *	Date Mar.2004
 *
/*****************************************************************************/
#define	STRICT
#include <windows.h>
#include <tchar.h>
#include <string.h>


#include "serial.h"

#define WM_AXCAC01				( WM_USER + 100 )
#define WM_AXCAC01_AD			( WM_AXCAC01 + 1 )
#define WM_AXCAC01_DA			( WM_AXCAC01 + 2 )
#define WM_AXCAC01_GPIO			( WM_AXCAC01 + 3 )


BOOL	OnCreate( HWND hWnd );
BOOL	OnDestroy( void );
BOOL	OnADProcess( HWND hWnd );
BOOL	OnDAProcess( HWND hWnd );
BOOL	OnGPIOProcess( HWND hWnd );
LRESULT CALLBACK WndProc(HWND, UINT, WPARAM, LPARAM);


static void ResultMessage(LPWSTR);
static void ErrorMessage(LPWSTR);
static void	TimeErrorMessage(LPWSTR);
static void	ResponseErrorMessage(LPWSTR);

#define	CMD_MESSAGE_SIZE	10
static BOOL	CommandOut(LPSTR);

const WCHAR szMessage[]	= _T("AXC-AC01 Sample");
const WCHAR szError[]	= _T("Sample Error");
const WCHAR szAC01[] = _T("AXC-AC01");
WCHAR		szbuf[1024];
WORD		wLogSocket;					// foCXi[
WCHAR		szClassName[] = _T(" ۸");

/*===================================================================
// C
//=================================================================*/
int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
										LPWSTR lpCmdLine, int nCmdShow)
{
	MSG			msg;
	WNDCLASS	wc;
	HWND		hWnd;

	/*---------------------------------------------------------------
	// EChENXo^
	//-------------------------------------------------------------*/
	if (!hPrevInstance) {
		wc.style			= CS_HREDRAW | CS_VREDRAW;
		wc.lpfnWndProc		= WndProc;
		wc.cbClsExtra		= 0;
		wc.cbWndExtra		= 0;
		wc.hInstance		= hInstance;
		wc.hIcon			= NULL;
		wc.hCursor			= LoadCursor(NULL, IDC_ARROW);
		wc.hbrBackground	= GetStockObject(WHITE_BRUSH);
		wc.lpszMenuName		= NULL;
		wc.lpszClassName	= szClassName;
		if (!RegisterClass(&wc)) return FALSE;
	}
	/*---------------------------------------------------------------
	// EChE쐬
	//-------------------------------------------------------------*/
	hWnd = CreateWindow(szClassName,
		szAC01,
		WS_VISIBLE,
		CW_USEDEFAULT,
		CW_USEDEFAULT,
		CW_USEDEFAULT,
		CW_USEDEFAULT,
		NULL,
		NULL,
		hInstance,
		NULL);

	if ( hWnd == NULL ) return FALSE;
	/*---------------------------------------------------------------
	// EChE\
	//-------------------------------------------------------------*/
	ShowWindow(hWnd, nCmdShow);
	UpdateWindow(hWnd);
	//---------------------------------------------------------------
	// bZ[W[v
	//---------------------------------------------------------------
	while (GetMessage(&msg, NULL, 0, 0)) 
	{
		TranslateMessage(&msg);
		DispatchMessage(&msg);
	}

	return (msg.wParam);
}
/*===================================================================
// EChEbZ[W
//=================================================================*/
LRESULT CALLBACK WndProc(HWND hWnd, UINT msg, WPARAM wParam, LPARAM lParam)
{
	switch (msg) {

		case WM_CREATE:
			OnCreate(hWnd);
			break;

		case WM_DESTROY:
			OnDestroy();
			PostQuitMessage(0);
			break;

		case WM_AXCAC01_AD:
			OnADProcess(hWnd);
			break;

		case WM_AXCAC01_DA:
			OnDAProcess(hWnd);
			break;

		case WM_AXCAC01_GPIO:
			OnGPIOProcess(hWnd);
			break;

		default:
			return(DefWindowProc(hWnd, msg, wParam, lParam));
	}
	return 0;
}
//===================================================================
// ckkJ
//===================================================================
BOOL OnDestroy( void )
{
	/*=================================================================
	 * COM|[g J
	 *===============================================================*/
	COMClosePort();	

	return TRUE;
}
//===================================================================
// ckk[h犄荞݋܂ł̏
//===================================================================
BOOL OnCreate( HWND hWnd )
{
	HMODULE		hDLL 			= NULL;
	FARPROC		pAxcac01GetPort	= NULL;
	LONG		lPort;
	WCHAR		szPortName[_MAX_PATH];
	char		cCmd[10];
	char		cData[80];

	/*=================================================================
	 * Axcac01.dll ̎gp錾
	 *===============================================================*/
	hDLL = (HMODULE)LoadLibrary(_T("Axcac01.dll"));
	if (hDLL == NULL) 
	{
		ErrorMessage(_T("No Device Error!"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}

	pAxcac01GetPort = GetProcAddress(hDLL, _T("Axcac01FindComPort"));
	if(pAxcac01GetPort == NULL)
	{
		ErrorMessage(_T("No Device Error!(1)"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	lPort	= (*pAxcac01GetPort)();

	FreeLibrary(hDLL);

	wsprintf(szPortName,_T("COM%ld:"),lPort);
	if(!COMOpenPort(szPortName))
	{
		ErrorMessage(_T("No Device Error!(2)"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	
	sprintf(cCmd,"RS\r");
	if(!COMWritePort(cCmd, 3))
	{
		TimeErrorMessage(_T("RS(W)"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}

	sprintf(cCmd,"QU\r");
	if(!COMWritePort(cCmd, 3))
	{
		TimeErrorMessage(_T("QU(W)"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}

	if(!COMReadPort(cData, sizeof(cData)))
	{
		TimeErrorMessage(_T("QU"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}

	if(strstr(cData,"AXC-AC01") == NULL)
	{
		ResponseErrorMessage(_T("QU"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	ResultMessage(_T("Device Name:AXC-AC01"));

	if(!CommandOut("RM1\r"))
	{
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	
	PostMessage(hWnd, WM_AXCAC01_AD, (WPARAM)0, (LPARAM)0);

	return TRUE;
}
//===================================================================
// A/D ɑ΂鏈
//===================================================================
BOOL OnADProcess( HWND hWnd )
{
	char		cCmd[10];
	char		cData[4096];
	WCHAR		szBuff[4096];
	BOOL		bLoop;
	WORD		wNum;
	WORD		wResult[40];
	int			i,j;

	// VOGhݒ
	if(!CommandOut("AD0\r"))
	{
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	// TvO10.2secɂ
	if(!CommandOut("SC1\r"))
	{
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	if(!CommandOut("SK1\r"))
	{
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	if(!CommandOut("SU0\r"))
	{
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	
	// f[^1024
	if(!CommandOut("ML0\r"))
	{
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	
	// OgK
	if(!CommandOut("TS0\r"))
	{
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	
	wsprintf(szBuff,_T("A/D Sampling Setting\r\n")
					_T("Condition: Single-ended\r\n")
					_T("Rate: 10.2s\r\n")
					_T("Memory Data: 1024\r\n")
					_T("EXT Trigger: Disable\r\n"));
	ResultMessage(szBuff);

	// gKs
	sprintf(cCmd,"TG\r");
	if(!COMWritePort(cCmd, strlen(cCmd)))
	{
		TimeErrorMessage(_T("TG"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	if(!COMReadPort(cData, 2))
	{
		TimeErrorMessage(_T("TG"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	if(cData[0] != 2 || cData[1] != 1)	// ADC-DMA Start
	{
		ResponseErrorMessage(_T("TG"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	// DMA ]I҂
	bLoop	= TRUE;
	while(bLoop)
	{
		if(!COMReadPort(cData, 2))
		{
			TimeErrorMessage(_T("TG(2)"));
			PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
			return	FALSE;
		}
		if(cData[0] == 2 && cData[1] == 3)		// ADC-DMA Complete
		{
			bLoop	= FALSE;
		}
		else
		{
			ResponseErrorMessage(_T("TG(2)"));

			PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
			return	FALSE;
		}
	}

	// ubNf[^擾ioCij
	sprintf(cCmd,"BB0\r");
	if(!COMWritePort(cCmd, strlen(cCmd)))
	{
		TimeErrorMessage(_T("BB0"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	if(!COMReadPort(cData, (1024 * 2) + 3))
	{
		TimeErrorMessage(_T("BB0"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	wNum = (WORD)((BYTE)cData[1]) * 256 + (WORD)((BYTE)cData[2]);
	wNum = (wNum - 3) / 2;
	if(cData[0] != 0x20 || wNum != 1024)
	{
		ResponseErrorMessage(_T("BB0"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	j = 0;
	for(i = 0; i < 40 * 2; i += 2)
	{
		wResult[j++]	= (WORD)((BYTE)cData[i + 3]) * 256 + (WORD)((BYTE)cData[i + 4]);
	}
	wsprintf(szBuff,_T("A/D Sampling Data - Ch0\r\n")
					_T("%04xh,%04xh,%04xh,%04xh\r\n")
					_T("%04xh,%04xh,%04xh,%04xh\r\n")
					_T("%04xh,%04xh,%04xh,%04xh\r\n")
					_T("%04xh,%04xh,%04xh,%04xh\r\n")
					_T("%04xh,%04xh,%04xh,%04xh\r\n")
					_T("%04xh,%04xh,%04xh,%04xh\r\n")
					_T("%04xh,%04xh,%04xh,%04xh\r\n")
					_T("%04xh,%04xh,%04xh,%04xh\r\n")
					_T("%04xh,%04xh,%04xh,%04xh\r\n")
					_T("%04xh,%04xh,%04xh,%04xh\r\n"),
					wResult[ 0],wResult[ 1],wResult[ 2],wResult[ 3],
					wResult[ 4],wResult[ 5],wResult[ 6],wResult[ 7],
					wResult[ 8],wResult[ 9],wResult[10],wResult[11],
					wResult[12],wResult[13],wResult[14],wResult[15],
					wResult[16],wResult[17],wResult[18],wResult[19],
					wResult[20],wResult[21],wResult[22],wResult[23],
					wResult[24],wResult[25],wResult[26],wResult[27],
					wResult[28],wResult[29],wResult[30],wResult[31],
					wResult[32],wResult[33],wResult[34],wResult[35],
					wResult[36],wResult[37],wResult[38],wResult[39]);
	ResultMessage(szBuff);
	
	// A/DVOTvO
	sprintf(cCmd,"CB2\r");
	if(!COMWritePort(cCmd, strlen(cCmd)))
	{
		TimeErrorMessage(_T("CB2"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	if(!COMReadPort(cData, 5))
	{
		TimeErrorMessage(_T("CB2"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	if(cData[0] != 0x12)	// A/D Response
	{
		ResponseErrorMessage(_T("CB2"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	
	wResult[0] = (WORD)((BYTE)cData[1]) * 256 + (WORD)((BYTE)cData[2]);
	wResult[1] = (WORD)((BYTE)cData[3]) * 256 + (WORD)((BYTE)cData[4]);
	wsprintf(szBuff,_T("A/D Single Sampling Data\r\n")
					_T("Ch0: %04xh\r\n")
					_T("Ch1: %04xh\r\n"),
					wResult[ 0],wResult[ 1]);
	ResultMessage(szBuff);
	
	PostMessage(hWnd, WM_AXCAC01_DA, (WPARAM)0, (LPARAM)0);

	return	TRUE;
}
//===================================================================
// D/A ɑ΂鏈
//===================================================================
BOOL OnDAProcess( HWND hWnd )
{
	char		cCmd[10];
	char		cData[10];
	WCHAR		szBuff[4096];
	WORD		wData	= 0x555;

	// A/DVOTvO
	sprintf(cCmd,"DB0   \r");
	cCmd[4]	= (char)((wData >> 8) & 0xff);
	cCmd[5]	= (char)(wData & 0xff);
	if(!COMWritePort(cCmd, strlen(cCmd)))
	{
		TimeErrorMessage(_T("DB"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	if(!COMReadPort(cData, 2))
	{
		TimeErrorMessage(_T("DB"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	if(cData[0] != 0 || cData[1] != 0)	// D/A Response
	{
		ResponseErrorMessage(_T("DB"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	
	wsprintf(szBuff,_T("D/A Output - Ch0\r\n")
					_T("Value: %04xh\r\n"),
					wData);
	ResultMessage(szBuff);

	PostMessage(hWnd, WM_AXCAC01_GPIO, (WPARAM)0, (LPARAM)0);

	return	TRUE;
}
//===================================================================
// GPIO ɑ΂鏈
//===================================================================
BOOL OnGPIOProcess( HWND hWnd )
{
	char		cCmd[10];
	char		cData[10];
	WCHAR		szBuff[4096];
	WORD		wData	= 0x555;
	int			nResult[4];

	// Port-A Input Port
	if(!CommandOut("GA0\r"))
	{
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	// Port-B Input Port
	if(!CommandOut("GB0\r"))
	{
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	// Port-C Input Port
	if(!CommandOut("GC0\r"))
	{
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	// Port-D Input Port
	if(!CommandOut("GD0\r"))
	{
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	wsprintf(szBuff,_T("GPIO Port Setting\r\n")
					_T("Port A: Input\r\n")
					_T("Port B: Input\r\n")
					_T("Port C: Input\r\n")
					_T("Port D: Input\r\n"));
	ResultMessage(szBuff);

	// Port-A Input
	sprintf(cCmd,"QP0\r");
	if(!COMWritePort(cCmd, strlen(cCmd)))
	{
		TimeErrorMessage(_T("QP0"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	if(!COMReadPort(cData, 1))
	{
		TimeErrorMessage(_T("QP0"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	nResult[0]	= (INT)cData[0];

	// Port-B Input
	sprintf(cCmd,"QP1\r");
	if(!COMWritePort(cCmd, strlen(cCmd)))
	{
		TimeErrorMessage(_T("QP1"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	if(!COMReadPort(cData, 1))
	{
		TimeErrorMessage(_T("QP1"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	nResult[1]	= (INT)cData[0];

	// Port-C Input
	sprintf(cCmd,"QP2\r");
	if(!COMWritePort(cCmd, strlen(cCmd)))
	{
		TimeErrorMessage(_T("QP2"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	if(!COMReadPort(cData, 1))
	{
		TimeErrorMessage(_T("QP2"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	nResult[2]	= (INT)cData[0];

	// Port-D Input
	sprintf(cCmd,"QP3\r");
	if(!COMWritePort(cCmd, strlen(cCmd)))
	{
		TimeErrorMessage(_T("QP3"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	if(!COMReadPort(cData, 1))
	{
		TimeErrorMessage(_T("QP3"));
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	nResult[3]	= (INT)cData[0];

	wsprintf(szBuff,_T("GPIO Input Data\r\n")
					_T("Port A: %d\r\n")
					_T("Port B: %d\r\n")
					_T("Port C: %d\r\n")
					_T("Port D: %d\r\n"),
					nResult[0],nResult[1],nResult[2],nResult[3]);
	ResultMessage(szBuff);


	// Port-A Push-Pull Output Port
	if(!CommandOut("GA2\r"))
	{
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	// Port-B Push-Pull Output Port
	if(!CommandOut("GB2\r"))
	{
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	// Port-C Push-Pull Output Port
	if(!CommandOut("GC2\r"))
	{
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	// Port-D Push-Pull Output Port
	if(!CommandOut("GD2\r"))
	{
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	wsprintf(szBuff,_T("GPIO Port Setting\r\n")
					_T("Port A: Push-Pull Output\r\n")
					_T("Port B: Push-Pull Output\r\n")
					_T("Port C: Push-Pull Output\r\n")
					_T("Port D: Push-Pull Output\r\n"));
	ResultMessage(szBuff);

	// Port-A Output 0(Low)
	if(!CommandOut("PA0\r"))
	{
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	// Port-B Output 1(High)
	if(!CommandOut("PB1\r"))
	{
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	// Port-C Output 0(Low)
	if(!CommandOut("PC0\r"))
	{
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	// Port-D Output 1(High)
	if(!CommandOut("PD1\r"))
	{
		PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
		return	FALSE;
	}
	wsprintf(szBuff,_T("GPIO OutPort Data\r\n")
					_T("Port A: 0\r\n")
					_T("Port B: 1\r\n")
					_T("Port C: 0\r\n")
					_T("Port D: 1\r\n"));
	ResultMessage(szBuff);

	PostMessage(hWnd, WM_DESTROY, (WPARAM)0, (LPARAM)0);
	return	TRUE;
}
/*-------------------------------------------------------------------
// R}ho͏siX|X擾܂Łj
//-----------------------------------------------------------------*/
static BOOL CommandOut(char* pCmd)
{
	WCHAR	wszMessage[CMD_MESSAGE_SIZE];
	char	cData[40];

	MultiByteToWideChar(CP_ACP,
						MB_PRECOMPOSED,
						pCmd,
						strlen(pCmd),
						wszMessage,
						CMD_MESSAGE_SIZE);


	if(!COMWritePort(pCmd, strlen(pCmd)))
	{
		TimeErrorMessage(wszMessage);
		COMClosePort();
		return	FALSE;
	}
	if(!COMReadPort(cData, 2))
	{
		TimeErrorMessage(wszMessage);
		COMClosePort();
		return	FALSE;
	}
	if(cData[0] != 0 || cData[1] != 0)
	{
		ResponseErrorMessage(wszMessage);
		COMClosePort();
		return	FALSE;
	}
	return	TRUE;
}
/*-------------------------------------------------------------------
// ʂ\
//-----------------------------------------------------------------*/
static void ResultMessage(LPWSTR lpszbuf)
{
	MessageBox(NULL, lpszbuf, szMessage, MB_OK | MB_ICONINFORMATION);
}
/*-------------------------------------------------------------------
// G[bZ[W\
//-----------------------------------------------------------------*/
static void ErrorMessage(LPWSTR pwMessage)
{
	MessageBox(NULL, pwMessage, szError, MB_OK | MB_ICONSTOP);
}
/*-------------------------------------------------------------------
// ^CAEgG[@bZ[W\
//-----------------------------------------------------------------*/
static void	TimeErrorMessage(LPWSTR	pwCmdName)
{
	WCHAR	szBuff[80];
//	WCHAR	szBuff2;
	
//	wcsncpy(szBuff2,pwCmdName,wcslen(pwCmdName)-1);
	
	wsprintf(szBuff,_T("Command Timeout Error!\r\n")
					_T("Command Name: %s\r\n"),pwCmdName);
	MessageBox(NULL, szBuff, szError, MB_OK | MB_ICONSTOP);
}
/*-------------------------------------------------------------------
// G[@bZ[W\
//-----------------------------------------------------------------*/
static void	ResponseErrorMessage(LPWSTR pwCmdName)
{
	WCHAR	szBuff[80];
//	WCHAR	szBuff2;
	
//	wcsncpy(szBuff2,pwCmdName,wcslen(pwCmdName)-1);
	
	wsprintf(szBuff,_T("Command Response Error!\r\n")
					_T("Command Name: %s\r\n"),pwCmdName);
	MessageBox(NULL, szBuff, szError, MB_OK | MB_ICONSTOP);
}

